@@ -1,9 +1,7 @@
 # -*- coding: utf-8 -*-
+from cms.compat import get_user_model
 from cms.utils import get_cms_setting
-from django.conf import settings
-from django.core.cache import cache
 
-from django.contrib.auth.models import User
 
 PERMISSION_KEYS = [
     'can_change', 'can_add', 'can_delete',
@@ -13,13 +11,15 @@ PERMISSION_KEYS = [
 
 
 def get_cache_key(user, key):
+    username = getattr(user, get_user_model().USERNAME_FIELD)
     return "%s:permission:%s:%s" % (
-        get_cms_setting('CACHE_PREFIX'), user.username, key)
+        get_cms_setting('CACHE_PREFIX'), username, key)
 
 def get_cache_version_key():
     return "%s:permission:version" % (get_cms_setting('CACHE_PREFIX'),)
 
 def get_cache_version():
+    from django.core.cache import cache
     version = cache.get(get_cache_version_key())
     if version is None:
         version = 1
@@ -30,6 +30,7 @@ def get_permission_cache(user, key):
     """
     Helper for reading values from cache
     """
+    from django.core.cache import cache
     return cache.get(get_cache_key(user, key), version=get_cache_version())
 
 
@@ -38,6 +39,7 @@ def set_permission_cache(user, key, value):
     Helper method for storing values in cache. Stores used keys so
     all of them can be cleaned when clean_permission_cache gets called.
     """
+    from django.core.cache import cache
     # store this key, so we can clean it when required
     cache_key = get_cache_key(user, key)
     cache.set(cache_key, value,
@@ -49,11 +51,13 @@ def clear_user_permission_cache(user):
     """
     Cleans permission cache for given user.
     """
+    from django.core.cache import cache
     for key in PERMISSION_KEYS:
         cache.delete(get_cache_key(user, key), version=get_cache_version())
 
 
 def clear_permission_cache():
+    from django.core.cache import cache
     version = get_cache_version()
     if version > 1:
         cache.incr(get_cache_version_key())
