@@ -17,7 +17,13 @@ class PluginLimitReached(Exception):
 class AppAlreadyRegistered(Exception):
     pass
 
-AppAllreadyRegistered = AppAlreadyRegistered # backwards compatibility, will be dropped in 2.3
+
+class ToolbarAlreadyRegistered(Exception):
+    pass
+
+class ToolbarNotRegistered(Exception):
+    pass
+
 
 class NotImplemented(Exception):
     pass
@@ -44,11 +50,18 @@ class NoPermissionsException(PermissionsException):
     """Can be fired when some violate action is performed on permission system. 
     """
 
+
 class PublicIsUnmodifiable(Exception):
     """A method was invoked on the public copy, but is only valid for the
     draft version"""
     pass
 
+
+class PublicVersionNeeded(Exception):
+    """A Public version of this page is needed"""
+    pass
+
+
 class Deprecated(Exception): pass
 
 
@@ -62,3 +75,10 @@ class CMSDeprecationWarning(Warning): pass
 
 
 class LanguageError(Exception): pass
+
+
+class PluginConsistencyError(Exception): pass
+
+
+class PlaceholderNotFound(Exception): pass
+
