@@ -5,6 +5,7 @@ from cms.models.query import PageQuerySet
 from cms.publisher import PublisherManager
 from cms.utils import get_cms_setting
 from cms.utils.i18n import get_fallback_languages
+from cms.compat import user_related_query_name
 from django.contrib.sites.models import Site
 from django.db import models
 from django.db.models import Q
@@ -24,9 +25,7 @@ class PageManager(PublisherManager):
         return super(PageManager, self).drafts()
 
     def public(self):
-        return super(PageManager, self).public().exclude(
-            publisher_state=self.model.PUBLISHER_STATE_DELETE
-        )
+        return super(PageManager, self).public()
 
     # !IMPORTANT: following methods always return access to draft instances,
     # take care on what you do one them. use Page.objects.public() for accessing
@@ -155,10 +154,10 @@ class TitleManager(PublisherManager):
 
     # created new public method to meet test case requirement and to get a list of titles for published pages
     def public(self):
-        return self.get_query_set().filter(page__publisher_is_draft=False, page__published=True)
+        return self.get_query_set().filter(publisher_is_draft=False, published=True)
 
     def drafts(self):
-        return self.get_query_set().filter(page__publisher_is_draft=True)
+        return self.get_query_set().filter(publisher_is_draft=True)
 
     def set_or_create(self, request, page, form, language):
         """
@@ -168,12 +167,10 @@ class TitleManager(PublisherManager):
             'slug',
             'title',
             'meta_description',
-            'meta_keywords',
             'page_title',
             'menu_title'
         ]
         advanced_fields = [
-            'application_urls',
             'redirect',
         ]
         cleaned_data = form.cleaned_data
@@ -191,21 +188,24 @@ class TitleManager(PublisherManager):
                 if overwrite_url:
                     data['has_url_overwrite'] = True
                     data['path'] = overwrite_url
+                else:
+                    data['has_url_overwrite'] = False
                 for field in advanced_fields:
                     value = cleaned_data.get(field, None)
-                    if value:
-                        data[field] = value
+                    data[field] = value
             return self.create(**data)
-
         for name in base_fields:
-            value = cleaned_data.get(name, None)
-            setattr(obj, name, value)
+            if name in form.base_fields:
+                value = cleaned_data.get(name, None)
+                setattr(obj, name, value)
         if page.has_advanced_settings_permission(request):
             overwrite_url = cleaned_data.get('overwrite_url', None)
             obj.has_url_overwrite = bool(overwrite_url)
             obj.path = overwrite_url
             for field in advanced_fields:
-                setattr(obj, field, cleaned_data.get(field, None))
+                if field in form.base_fields:
+                    value = cleaned_data.get(field, None)
+                    setattr(obj, field, value)
         obj.save()
         return obj
 
@@ -217,14 +217,18 @@ class TitleManager(PublisherManager):
 class BasicPagePermissionManager(models.Manager):
     """Global page permission manager accessible under objects.
 
-    !IMPORTANT: take care, PagePermissionManager extends this manager
+    !IMPORTANT: take care, PagePermissionManager and GlobalPagePermissionManager
+    both inherit from this manager
     """
 
     def with_user(self, user):
         """Get all objects for given user, also takes look if user is in some
         group.
         """
-        return self.filter(Q(user=user) | Q(group__user=user))
+        query = dict()
+        query['group__' + user_related_query_name] = user
+
+        return self.filter(Q(user=user) | Q(**query))
 
     def with_can_change_permissions(self, user):
         """Set of objects on which user haves can_change_permissions. !But only
@@ -234,6 +238,29 @@ class BasicPagePermissionManager(models.Manager):
         return self.with_user(user).filter(can_change_permissions=True)
 
 
+class GlobalPagePermissionManager(BasicPagePermissionManager):
+ 
+    def user_has_permission(self, user, site_id, perm):
+        """
+        Provide a single point of entry for deciding whether any given global
+        permission exists.
+        """
+        # if the user has add rights to this site explicitly
+        this_site = Q(**{perm: True, 'sites__in':[site_id]})
+        # if the user can add to all sites
+        all_sites = Q(**{perm: True, 'sites__isnull': True})
+        return self.with_user(user).filter(this_site | all_sites)
+ 
+    def user_has_add_permission(self, user, site_id):
+        return self.user_has_permission(user, site_id, 'can_add')
+ 
+    def user_has_change_permission(self, user, site_id):
+        return self.user_has_permission(user, site_id, 'can_change')
+ 
+    def user_has_view_permission(self, user, site_id):
+        return self.user_has_permission(user, site_id, 'can_view')
+ 
+  
 class PagePermissionManager(BasicPagePermissionManager):
     """Page permission manager accessible under objects.
     """
@@ -328,20 +355,27 @@ class PagePermissionManager(BasicPagePermissionManager):
         """
         # permissions should be managed on the draft page only
         page = page.get_draft_object()
-        from cms.models import ACCESS_DESCENDANTS, ACCESS_CHILDREN, \
-            ACCESS_PAGE_AND_CHILDREN, ACCESS_PAGE_AND_DESCENDANTS, ACCESS_PAGE
+        from cms.models import (ACCESS_DESCENDANTS, ACCESS_CHILDREN,
+            ACCESS_PAGE_AND_CHILDREN, ACCESS_PAGE_AND_DESCENDANTS, ACCESS_PAGE)
 
-        parents = Q(page__tree_id=page.tree_id, page__lft__lte=page.lft, page__rght__gte=page.rght) & (
+        if page.level is None or page.lft is None or page.rght is None:
+            raise ValueError("Cannot use unsaved page for permission lookup, missing MPTT attributes.")
+
+        parents = Q(page__tree_id=page.tree_id) & (
             Q(grant_on=ACCESS_DESCENDANTS) | Q(grant_on=ACCESS_PAGE_AND_DESCENDANTS))
         direct_parents = Q(
             page__tree_id=page.tree_id,
-            page__lft__lte=page.lft,
-            page__rght__gte=page.rght,
-            page__level=page.level - 1) & \
-            (Q(grant_on=ACCESS_CHILDREN) | Q(grant_on=ACCESS_PAGE_AND_CHILDREN))
+            page__level=page.level - 1) & (
+                             Q(grant_on=ACCESS_CHILDREN) | Q(grant_on=ACCESS_PAGE_AND_CHILDREN)
+                         )
         page_qs = Q(page=page) & (
             Q(grant_on=ACCESS_PAGE_AND_DESCENDANTS) | Q(grant_on=ACCESS_PAGE_AND_CHILDREN) | Q(grant_on=ACCESS_PAGE))
 
+        parents = parents & Q(page__lft__lte=page.lft)
+        direct_parents = direct_parents & Q(page__lft__lte=page.lft)
+        parents = parents & Q(page__rght__gte=page.rght)
+        direct_parents = direct_parents & Q(page__rght__gte=page.rght)
+
         query = (parents | direct_parents | page_qs)
         return self.filter(query).order_by('page__level')
 
@@ -408,27 +442,34 @@ class PagePermissionsPermissionManager(models.Manager):
         """
         return self.__get_id_list(user, site, "can_view")
 
-    '''
-    def get_change_list_id_list(self, user, site):
-        """This is used just in admin now. Gives all ids where user haves can_edit
-        and can_add merged together.
+    def get_restricted_id_list(self, site):
+        from cms.models import (GlobalPagePermission, PagePermission,
+            MASK_CHILDREN, MASK_DESCENDANTS, MASK_PAGE)
 
-        There is for sure a better way how to do this over sql, need to be
-        optimized...
-        """
-        can_change = self.get_change_id_list(user)
-        can_add = self.get_add_id_list(user)
-        if can_change is can_add:
-            # GRANT_ALL case
-            page_id_list = can_change
-        else:
-            permission_set = filter(lambda i: not i is PagePermissionsPermissionManager.GRANT_ALL, [can_change, can_add])
-            if len(permission_set) is 1:
-                page_id_list = permission_set[0]
-            else:
-                page_id_list = list(set(can_change).union(set(can_add)))
-        return page_id_list
-    '''
+        global_permissions = GlobalPagePermission.objects.all()
+        if global_permissions.filter(**{
+            'can_view': True, 'sites__in': [site]
+        }).exists():
+            # user or his group are allowed to do `attr` action
+            # !IMPORTANT: page permissions must not override global permissions
+            from cms.models import Page
+
+            return Page.objects.filter(site=site).values_list('id', flat=True)
+            # for standard users without global permissions, get all pages for him or
+        # his group/s
+        qs = PagePermission.objects.filter(page__site=site, can_view=True).select_related('page')
+        qs.order_by('page__tree_id', 'page__level', 'page__lft')
+        # default is denny...
+        page_id_allow_list = []
+        for permission in qs:
+            if permission.grant_on & MASK_PAGE:
+                page_id_allow_list.append(permission.page.id)
+            if permission.grant_on & MASK_CHILDREN:
+                page_id_allow_list.extend(permission.page.get_children().values_list('id', flat=True))
+            elif permission.grant_on & MASK_DESCENDANTS:
+                page_id_allow_list.extend(permission.page.get_descendants().values_list('id', flat=True))
+                # store value in cache
+        return page_id_allow_list
 
     def __get_id_list(self, user, site, attr):
         from cms.models import (GlobalPagePermission, PagePermission,
@@ -446,17 +487,16 @@ class PagePermissionsPermissionManager(models.Manager):
         if cached is not None:
             return cached
             # check global permissions
-        global_permissions = GlobalPagePermission.objects.with_user(user)
-        if global_permissions.filter(**{
-            attr: True, 'sites__in': [site]
-        }).exists():
+        global_perm = GlobalPagePermission.objects.user_has_permission(user, site, attr).exists()
+        if global_perm:
             # user or his group are allowed to do `attr` action
             # !IMPORTANT: page permissions must not override global permissions
             return PagePermissionsPermissionManager.GRANT_ALL
             # for standard users without global permissions, get all pages for him or
         # his group/s
         qs = PagePermission.objects.with_user(user)
-        qs.order_by('page__tree_id', 'page__level', 'page__lft')
+        qs.filter(**{'page__site': site}).order_by('page__tree_id', 'page__level',
+                                                               'page__lft').select_related('page')
         # default is denny...
         page_id_allow_list = []
         for permission in qs:
@@ -471,10 +511,3 @@ class PagePermissionsPermissionManager(models.Manager):
                     # store value in cache
         set_permission_cache(user, attr, page_id_allow_list)
         return page_id_allow_list
-
-
-class PageModeratorStateManager(models.Manager):
-    def get_delete_actions(self):
-        from cms.models import PageModeratorState
-
-        return self.filter(action=PageModeratorState.ACTION_DELETE)
