@@ -2,9 +2,10 @@
 from __future__ import with_statement
 
 from django.contrib.sites.models import Site
-from django.contrib.auth.models import AnonymousUser, User, Group
+from django.contrib.auth.models import AnonymousUser, Group
 
 from cms.api import create_page
+from cms.compat import get_user_model, user_related_name
 from cms.menu import get_visible_pages
 from cms.models import Page
 from cms.models import ACCESS_DESCENDANTS, ACCESS_CHILDREN, ACCESS_PAGE
@@ -13,6 +14,11 @@ from cms.models.permissionmodels import GlobalPagePermission, PagePermission
 from cms.test_utils.testcases import SettingsOverrideTestCase
 from menus.menu_pool import menu_pool
 
+__all__ = [
+    'ViewPermissionTreeBugTests',
+    'ViewPermissionComplexMenuAllNodesTests'
+]
+
 
 class ViewPermissionTests(SettingsOverrideTestCase):
     """
@@ -134,20 +140,16 @@ class ViewPermissionTests(SettingsOverrideTestCase):
             ('user_5_nostaff', False, self.GROUPNAME_5),
             ('user_staff', True, None),
         ]
+        default_users_count = get_user_model().objects.all().count()
         for username, is_staff, groupname in userdata:
-            user = User.objects.create(username=username,
-                                       email=username + '@domain.com',
-                                       is_active=True,
-                                       is_staff=is_staff)
-            user.set_password(username)
-            user.save()
+            user = self._create_user(username, is_staff)
             if groupname:
                 group, _ = Group.objects.get_or_create(name=groupname)
-                group.user_set.add(user)
+                user_set = getattr(group, user_related_name)
+                user_set.add(user)
                 group.save()
 
-        self.assertEquals(11, User.objects.all().count())
-
+        self.assertEqual(11, get_user_model().objects.all().count()-default_users_count)
 
     def _setup_view_restrictions(self):
         """
@@ -164,20 +166,20 @@ class ViewPermissionTests(SettingsOverrideTestCase):
             group = Group.objects.get(name__iexact=groupname)
             PagePermission.objects.create(can_view=True, group=group, page=page, grant_on=inherit)
 
-        self.assertEquals(5, PagePermission.objects.all().count())
-        self.assertEquals(0, GlobalPagePermission.objects.all().count())
+        self.assertEqual(5, PagePermission.objects.all().count())
+        self.assertEqual(0, GlobalPagePermission.objects.all().count())
 
     def assertPageFound(self, url, client=None):
         if not client:
             client = self.client
         response = client.get(url)
-        self.assertEquals(response.status_code, 200)
+        self.assertEqual(response.status_code, 200)
 
     def assertPageNotFound(self, url, client=None):
         if not client:
             client = self.client
         response = client.get(url)
-        self.assertEquals(response.status_code, 404)
+        self.assertEqual(response.status_code, 404)
 
     def assertViewAllowed(self, page, user):
         request = self.get_request(user, page)
@@ -234,12 +236,17 @@ class ViewPermissionTests(SettingsOverrideTestCase):
         # log the user in if present
         user = None
         if username is not None:
-            user = User.objects.get(username__iexact=username)
+            if get_user_model().USERNAME_FIELD == 'email':
+                username = username + '@django-cms.org'
+
+            query = dict()
+            query[get_user_model().USERNAME_FIELD+'__iexact'] = username
+            user = get_user_model().objects.get(**query)
         request = self.get_request(user)
         visible_page_ids = get_visible_pages(request, all_pages, self.site)
         public_page_ids = Page.objects.drafts().filter(title_set__title__in=expected_granted_pages).values_list('id',
                                                                                                                 flat=True)
-        self.assertEquals(len(visible_page_ids), len(expected_granted_pages))
+        self.assertEqual(len(visible_page_ids), len(expected_granted_pages))
         restricted_pages = Page.objects.public().exclude(title_set__title__in=expected_granted_pages).values_list('id',
                                                                                                                   flat=True)
         self.assertNodeMemberships(visible_page_ids, restricted_pages, public_page_ids)
@@ -278,7 +285,7 @@ class ViewPermissionComplexMenuAllNodesTests(ViewPermissionTests):
         all_pages = self._setup_tree_pages()
         request = self.get_request()
         visible_page_ids = get_visible_pages(request, all_pages, self.site)
-        self.assertEquals(len(all_pages), len(visible_page_ids))
+        self.assertEqual(len(all_pages), len(visible_page_ids))
         nodes = menu_pool.get_nodes(request)
         self.assertEqual(len(nodes), len(all_pages))
 
@@ -304,7 +311,7 @@ class ViewPermissionComplexMenuAllNodesTests(ViewPermissionTests):
         user = AnonymousUser()
         request = self.get_request(user, urls['/en/'])
         nodes = menu_pool.get_nodes(request)
-        self.assertEquals(len(nodes), 4)
+        self.assertEqual(len(nodes), 4)
         self.assertInMenu(urls["/en/"], user)
         self.assertInMenu(urls["/en/page_c/"], user)
         self.assertInMenu(urls["/en/page_c/page_c_a/"], user)
@@ -340,7 +347,12 @@ class ViewPermissionComplexMenuAllNodesTests(ViewPermissionTests):
             'page_d_d'
         ]
         urls = self.get_url_dict(all_pages)
-        user = User.objects.get(username='user_1')
+        
+        if get_user_model().USERNAME_FIELD == 'email':
+            user = get_user_model().objects.get(email='user_1@django-cms.org')
+        else:
+            user = get_user_model().objects.get(username='user_1')
+
         self.assertGrantedVisibility(all_pages, granted, username='user_1')
         self.assertViewAllowed(urls["/en/page_b/"], user)
         self.assertInMenu(urls["/en/page_b/"], user)
@@ -381,7 +393,12 @@ class ViewPermissionComplexMenuAllNodesTests(ViewPermissionTests):
         ]
         self.assertGrantedVisibility(all_pages, granted, username='user_2')
         urls = self.get_url_dict(all_pages)
-        user = User.objects.get(username='user_2')
+        
+        if get_user_model().USERNAME_FIELD == 'email':
+            user = get_user_model().objects.get(email='user_2@django-cms.org')
+        else:
+            user = get_user_model().objects.get(username='user_2')
+
         self.assertViewNotAllowed(urls["/en/page_b/page_b_b/"], user)
         self.assertViewAllowed(urls["/en/page_b/page_b_b/page_b_b_a/"], user)
         self.assertViewNotAllowed(urls["/en/page_b/page_b_b/page_b_b_a/page_b_b_a_a/"], user)
@@ -419,7 +436,12 @@ class ViewPermissionComplexMenuAllNodesTests(ViewPermissionTests):
         ]
         self.assertGrantedVisibility(all_pages, granted, username='user_3')
         urls = self.get_url_dict(all_pages)
-        user = User.objects.get(username='user_3')
+        
+        if get_user_model().USERNAME_FIELD == 'email':
+            user = get_user_model().objects.get(email='user_3@django-cms.org')
+        else:
+            user = get_user_model().objects.get(username='user_3')
+
         self.assertViewAllowed(urls["/en/page_b/"], user)
         self.assertViewAllowed(urls["/en/page_b/page_b_d/page_b_d_a/"], user)
         self.assertViewNotAllowed(urls["/en/page_d/"], user)
@@ -448,7 +470,12 @@ class ViewPermissionComplexMenuAllNodesTests(ViewPermissionTests):
         ]
         self.assertGrantedVisibility(all_pages, granted, username='user_4')
         urls = self.get_url_dict(all_pages)
-        user = User.objects.get(username='user_4')
+
+        if get_user_model().USERNAME_FIELD == 'email':
+            user = get_user_model().objects.get(email='user_4@django-cms.org')
+        else:
+            user = get_user_model().objects.get(username='user_4')
+        
         self.assertViewNotAllowed(urls["/en/page_b/"], user)
         self.assertViewNotAllowed(urls["/en/page_b/page_b_b/"], user)
         self.assertViewAllowed(urls["/en/page_b/page_b_b/page_b_b_a/"], user)
@@ -475,7 +502,12 @@ class ViewPermissionComplexMenuAllNodesTests(ViewPermissionTests):
         ]
         self.assertGrantedVisibility(all_pages, granted, username='user_5')
         urls = self.get_url_dict(all_pages)
-        user = User.objects.get(username='user_5')
+
+        if get_user_model().USERNAME_FIELD == 'email':
+            user = get_user_model().objects.get(email='user_5@django-cms.org')
+        else:
+            user = get_user_model().objects.get(username='user_5')
+        
         # call /
         self.assertViewNotAllowed(urls["/en/page_b/"], user)
         self.assertViewNotAllowed(urls["/en/page_b/page_b_b/"], user)
@@ -528,11 +560,10 @@ class ViewPermissionTreeBugTests(ViewPermissionTests):
         ]
 
     def _setup_user(self):
-        user = User.objects.create(username='user_6', email='user_6@domain.com', is_active=True, is_staff=True)
-        user.set_password(user.username)
-        user.save()
+        user = self._create_user('user_6', True)
         group = Group.objects.create(name=self.GROUPNAME_6)
-        group.user_set.add(user)
+        user_set = getattr(group, user_related_name)
+        user_set.add(user)
         group.save()
 
     def _setup_permviewbug(self):
@@ -552,10 +583,10 @@ class ViewPermissionTreeBugTests(ViewPermissionTests):
             perm = PagePermission.objects.for_page(page=page)
             # only page_6 has a permission assigned
             if page.get_title() == 'page_6':
-                self.assertEquals(len(perm), 2)
+                self.assertEqual(len(perm), 2)
             else:
                 msg = "Permission wrong at page %s" % (page.get_title())
-                self.assertEquals(len(perm), 0, msg)
+                self.assertEqual(len(perm), 0, msg)
         granted = ['page_1',
             'page_2',
             'page_3',
@@ -579,7 +610,11 @@ class ViewPermissionTreeBugTests(ViewPermissionTests):
         ]
 
         self.assertGrantedVisibility(all_pages, granted, username='user_6')
-        user = User.objects.get(username='user_6')
+
+        if get_user_model().USERNAME_FIELD == 'email':
+            user = get_user_model().objects.get(email='user_6@django-cms.org')
+        else:
+            user = get_user_model().objects.get(username='user_6')
         url = "/en/page_2/page_3/page_4/"
         self.assertViewAllowed(urls[url], user)
         url = "/en/page_5/page_6/"
