@@ -309,6 +309,6 @@ class MultilingualTestCase(SettingsOverrideTestCase):
         page.publish('en')
         superuser = self.get_superuser()
         with self.login_user_context(superuser):
-            response = self.client.get('/en/?edit')
+            response = self.client.get('/en/?%s' % get_cms_setting('CMS_TOOLBAR_URL__EDIT_ON'))
             self.assertEqual(response.status_code, 200)
 
