@@ -1,25 +1,22 @@
 # -*- coding: utf-8 -*-
 from __future__ import with_statement
+
+from django.template import Template
+
 from cms.api import create_page
 from cms.models import Page
 from cms.test_utils.testcases import CMSTestCase
-from cms.test_utils.util.context_managers import SettingsOverride
-from cms.utils.i18n import force_language
-from django.contrib.auth.models import User
-from django.middleware.locale import LocaleMiddleware
-from django.template import Template
-from menus.base import NavigationNode
-from django.http import HttpResponse
 from cms.templatetags.cms_admin import preview_link
+from cms.utils.i18n import force_language
+from menus.base import NavigationNode
 
 
 class NonRootCase(CMSTestCase):
     urls = 'cms.test_utils.project.nonroot_urls'
 
     def setUp(self):
-        u = User(username="test", is_staff = True, is_active = True, is_superuser = True)
-        u.set_password("test")
-        u.save()
+        u = self._create_user("test", True, True)
+
         with self.login_user_context(u):
             self.create_some_pages()
 
@@ -51,8 +48,8 @@ class NonRootCase(CMSTestCase):
 
     def test_basic_cms_menu(self):
         response = self.client.get(self.get_pages_root())
-        self.assertEquals(response.status_code, 200)
-        self.assertEquals(self.get_pages_root(), "/en/content/")
+        self.assertEqual(response.status_code, 200)
+        self.assertEqual(self.get_pages_root(), "/en/content/")
 
     def test_show_menu(self):
         context = self.get_context()
