@@ -3,6 +3,7 @@
 from __future__ import with_statement
 import datetime
 import re
+from cms.utils.conf import get_cms_setting
 
 from django.template.defaultfilters import truncatewords
 from django.contrib.auth.models import AnonymousUser, Permission
@@ -15,7 +16,7 @@ from django.core.urlresolvers import reverse
 from cms.models import UserSettings, PagePermission
 from cms.models import Page
 from cms.views import details
-from cms.api import create_page, create_title
+from cms.api import create_page, create_title, add_plugin
 from cms.cms_toolbar import ADMIN_MENU_IDENTIFIER, ADMINISTRATION_BREAK
 from cms.compat import is_user_swapped
 from cms.toolbar.items import (ToolbarAPIMixin, LinkItem, ItemSearchResult,
@@ -36,7 +37,7 @@ class ToolbarTestBase(SettingsOverrideTestCase):
     def get_page_request(self, page, user, path=None, edit=False, lang_code='en'):
         path = path or page and page.get_absolute_url()
         if edit:
-            path += '?edit'
+            path += '?%s' % get_cms_setting('CMS_TOOLBAR_URL__EDIT_ON')
         request = RequestFactory().get(path)
         request.session = {}
         request.user = user
@@ -134,7 +135,7 @@ class ToolbarTests(ToolbarTestBase):
         create_page("toolbar-page", "nav_playground.html", "en", published=True)
         superuser = self.get_superuser()
         with self.login_user_context(superuser):
-            response = self.client.get('/en/?edit')
+            response = self.client.get('/en/?%s' % get_cms_setting('CMS_TOOLBAR_URL__EDIT_ON'))
         self.assertEqual(response.status_code, 200)
         self.assertTemplateUsed(response, 'nav_playground.html')
         self.assertContains(response, '<div id="cms_toolbar"')
@@ -144,7 +145,7 @@ class ToolbarTests(ToolbarTestBase):
         create_page("toolbar-page", "col_two.html", "en", published=True)
         superuser = self.get_superuser()
         with self.login_user_context(superuser):
-            response = self.client.get('/en/?edit')
+            response = self.client.get('/en/?%s' % get_cms_setting('CMS_TOOLBAR_URL__EDIT_ON'))
         self.assertEqual(response.status_code, 200)
         self.assertContains(response, '<div class="cms_submenu-item cms_submenu-item-title"><span>Generic</span>')
 
@@ -152,7 +153,7 @@ class ToolbarTests(ToolbarTestBase):
         superuser = self.get_superuser()
         create_page("toolbar-page", "col_two.html", "en", published=True)
         with self.login_user_context(superuser):
-            response = self.client.get('/en/?edit')
+            response = self.client.get('/en/?%s' % get_cms_setting('CMS_TOOLBAR_URL__EDIT_ON'))
         self.assertEqual(response.status_code, 200)
         self.assertContains(response, 'href="LinkPlugin">')
         self.assertContains(response,
@@ -245,7 +246,7 @@ class ToolbarTests(ToolbarTestBase):
             superuser = self.get_superuser()
             create_page("toolbar-page", "col_two.html", "en", published=True)
             with self.login_user_context(superuser):
-                response = self.client.get('/en/?edit')
+                response = self.client.get('/en/?%s' % get_cms_setting('CMS_TOOLBAR_URL__EDIT_ON'))
             self.assertEqual(response.status_code, 200)
             self.assertContains(response, 'PPPP')
 
@@ -259,13 +260,13 @@ class ToolbarTests(ToolbarTestBase):
         create_page('test', 'nav_playground.html', 'en', published=True)
         superuser = self.get_superuser()
         with self.login_user_context(superuser):
-            response = self.client.get('/en/?edit')
+            response = self.client.get('/en/?%s' % get_cms_setting('CMS_TOOLBAR_URL__EDIT_ON'))
             self.assertEqual(response.status_code, 200)
             setting = UserSettings.objects.get(user=superuser)
             setting.language = 'it'
             setting.save()
             with SettingsOverride(LANGUAGES=(('en', 'english'),)):
-                response = self.client.get('/en/?edit')
+                response = self.client.get('/en/?%s' % get_cms_setting('CMS_TOOLBAR_URL__EDIT_ON'))
                 self.assertEqual(response.status_code, 200)
                 self.assertNotContains(response, '/it/')
 
@@ -362,7 +363,7 @@ class ToolbarTests(ToolbarTestBase):
         # first_name and last_name haven't been provided.
         #
         with self.login_user_context(superuser):
-            response = self.client.get(page.get_absolute_url('en') + '?edit')
+            response = self.client.get(page.get_absolute_url('en') + '?%s' % get_cms_setting('CMS_TOOLBAR_URL__EDIT_ON'))
             toolbar = response.context['request'].toolbar
             admin_menu = toolbar.get_or_create_menu(ADMIN_MENU_IDENTIFIER)
             if DJANGO_1_4:
@@ -381,7 +382,7 @@ class ToolbarTests(ToolbarTestBase):
         self.assertEqual('Super User', superuser.get_full_name())
         self.get_page_request(page, superuser, '/')
         with self.login_user_context(superuser):
-            response = self.client.get(page.get_absolute_url('en') + '?edit')
+            response = self.client.get(page.get_absolute_url('en') + '?%s' % get_cms_setting('CMS_TOOLBAR_URL__EDIT_ON'))
             toolbar = response.context['request'].toolbar
             admin_menu = toolbar.get_or_create_menu(ADMIN_MENU_IDENTIFIER)
             self.assertTrue(admin_menu.find_first(AjaxItem, name=_(u'Logout %s') % superuser.get_full_name()))
@@ -419,25 +420,25 @@ class ToolbarTests(ToolbarTestBase):
 
         with self.login_user_context(superuser):
             # Published page, no redirect
-            response = self.client.get(page1.get_absolute_url('en') + '?edit')
+            response = self.client.get(page1.get_absolute_url('en') + '?%s' % get_cms_setting('CMS_TOOLBAR_URL__EDIT_ON'))
             toolbar = response.context['request'].toolbar
             admin_menu = toolbar.get_or_create_menu(ADMIN_MENU_IDENTIFIER)
             self.assertTrue(admin_menu.find_first(AjaxItem, name=menu_name).item.on_success)
 
             # Unpublished page, redirect
-            response = self.client.get(page2.get_absolute_url('en') + '?edit')
+            response = self.client.get(page2.get_absolute_url('en') + '?%s' % get_cms_setting('CMS_TOOLBAR_URL__EDIT_ON'))
             toolbar = response.context['request'].toolbar
             admin_menu = toolbar.get_or_create_menu(ADMIN_MENU_IDENTIFIER)
             self.assertEquals(admin_menu.find_first(AjaxItem, name=menu_name).item.on_success, '/')
 
             # Published page with login restrictions, redirect
-            response = self.client.get(page3.get_absolute_url('en') + '?edit')
+            response = self.client.get(page3.get_absolute_url('en') + '?%s' % get_cms_setting('CMS_TOOLBAR_URL__EDIT_ON'))
             toolbar = response.context['request'].toolbar
             admin_menu = toolbar.get_or_create_menu(ADMIN_MENU_IDENTIFIER)
             self.assertEquals(admin_menu.find_first(AjaxItem, name=menu_name).item.on_success, '/')
 
             # Published page with view permissions, redirect
-            response = self.client.get(page4.get_absolute_url('en') + '?edit')
+            response = self.client.get(page4.get_absolute_url('en') + '?%s' % get_cms_setting('CMS_TOOLBAR_URL__EDIT_ON'))
             toolbar = response.context['request'].toolbar
             admin_menu = toolbar.get_or_create_menu(ADMIN_MENU_IDENTIFIER)
             self.assertEquals(admin_menu.find_first(AjaxItem, name=menu_name).item.on_success, '/')
@@ -525,6 +526,60 @@ class EditModelTemplateTagTest(ToolbarTestBase):
             response,
             '<div class="cms_plugin cms_plugin-%s cms_render_model"></div>' % ex1.pk)
 
+    def test_edit_render_placeholder(self):
+        """
+        Tests the {% render_placeholder %} templatetag.
+        """
+        user = self.get_staff()
+        page = create_page('Test', 'col_two.html', 'en', published=True)
+        ex1 = Example1(char_1="char_1", char_2="char_2", char_3="char_3",
+                       char_4="char_4")
+        ex1.save()
+
+        render_placeholder_body = "I'm the render placeholder body"
+
+        plugin = add_plugin(ex1.placeholder, u"TextPlugin", u"en", body=render_placeholder_body)
+
+        template_text = '''{% extends "base.html" %}
+{% load cms_tags %}
+
+{% block content %}
+<h1>{% render_placeholder instance.placeholder %}</h1>
+<h2>{% render_placeholder instance.placeholder as tempvar %}</h2>
+<h3>{{ tempvar }}</h3>
+{% endblock content %}
+'''
+        request = self.get_page_request(page, user, edit=True)
+        response = detail_view(request, ex1.pk, template_string=template_text)
+        self.assertContains(
+            response,
+            '<h1><div class="cms_placeholder cms_placeholder-{0}"></div>\n'
+            '<div class="cms_plugin cms_plugin-{1}">{2}</div></h1>'.format(ex1.placeholder.pk,
+                                                                           plugin.pk, render_placeholder_body)
+            )
+
+        self.assertContains(
+            response,
+            '<h2></h2>',
+        )
+
+        self.assertContains(
+            response,
+            '<h3><div class="cms_placeholder cms_placeholder-{0}"></div>\n'
+            '<div class="cms_plugin cms_plugin-{1}">{2}</div></h3>'.format(ex1.placeholder.pk,
+                                                                           plugin.pk, render_placeholder_body)
+            )
+
+        self.assertContains(
+            response,
+            'CMS.Plugin(\'cms_plugin-{0}\''.format(plugin.pk)
+        )
+
+        self.assertContains(
+            response,
+            'CMS.Plugin(\'cms_placeholder-{0}\''.format(ex1.placeholder.pk)
+        )
+
     def test_filters(self):
         user = self.get_staff()
         page = create_page('Test', 'col_two.html', 'en', published=True)
@@ -642,6 +697,38 @@ class EditModelTemplateTagTest(ToolbarTestBase):
             '<div class="cms_plugin cms_plugin-%s-%s-%s cms_render_model_icon"><img src="/static/cms/img/toolbar/render_model_placeholder.png"></div>' % (
                 'placeholderapp', 'example1', ex1.pk))
 
+    def test_icon_followed_by_render_model_block_tag(self):
+        user = self.get_staff()
+        page = create_page('Test', 'col_two.html', 'en', published=True)
+        ex1 = Example1(char_1="char_1", char_2="char_2", char_3="char_3",
+                       char_4="char_4", date_field=datetime.date(2012, 1, 1))
+        ex1.save()
+        template_text = '''{% extends "base.html" %}
+{% load cms_tags %}{% load url from future %}
+
+{% block content %}
+{% render_model_icon instance "char_1" %}
+
+{% render_model_block instance "char_2" %}
+    {{ instance }}
+    <h1>{{ instance.char_1 }} - {{  instance.char_2 }}</h1>
+    <span class="date">{{ instance.date_field|date:"Y" }}</span>
+    {% if instance.char_1 %}
+    <a href="{% url 'detail' instance.pk %}">successful if</a>
+    {% endif %}
+{% endrender_model_block %}
+{% endblock content %}
+'''
+        request = self.get_page_request(page, user, edit=True)
+        response = detail_view(request, ex1.pk, template_string=template_text)
+        self.assertContains(
+            response,
+            "new CMS.Plugin('cms_plugin-{0}-{1}-{2}-{3}'".format('placeholderapp', 'example1', 'char_1', ex1.pk))
+
+        self.assertContains(
+            response,
+            "new CMS.Plugin('cms_plugin-{0}-{1}-{2}-{3}'".format('placeholderapp', 'example1', 'char_2', ex1.pk))
+
     def test_add_tag(self):
         user = self.get_staff()
         page = create_page('Test', 'col_two.html', 'en', published=True)
@@ -1157,7 +1244,7 @@ class ToolbarAPITests(TestCase):
         self.assertEqual(result.index, 0)
 
     def test_not_is_staff(self):
-        request = RequestFactory().get('/en/?edit')
+        request = RequestFactory().get('/en/?%s' % get_cms_setting('CMS_TOOLBAR_URL__EDIT_ON'))
         request.session = {}
         request.LANGUAGE_CODE = 'en'
         request.user = AnonymousUser()
