@@ -123,7 +123,7 @@ class ViewTests(SettingsOverrideTestCase):
                     redirect='/en/page2')
         superuser = self.get_superuser()
         with self.login_user_context(superuser):
-            response = self.client.get('/en/?edit')
+            response = self.client.get('/en/?%s' % get_cms_setting('CMS_TOOLBAR_URL__EDIT_ON'))
             self.assertEqual(response.status_code, 200)
 
     def test_login_required(self):
@@ -146,13 +146,13 @@ class ViewTests(SettingsOverrideTestCase):
     def test_edit_permission(self):
         page = create_page("page", "nav_playground.html", "en", published=True)
         # Anon user
-        response = self.client.get("/en/?edit")
+        response = self.client.get("/en/?%s" % get_cms_setting('CMS_TOOLBAR_URL__EDIT_ON'))
         self.assertNotContains(response, "cms_toolbar-item_switch", 200)
 
         # Superuser
         user = self.get_superuser()
         with self.login_user_context(user):
-            response = self.client.get("/en/?edit")
+            response = self.client.get("/en/?%s" % get_cms_setting('CMS_TOOLBAR_URL__EDIT_ON'))
         self.assertContains(response, "cms_toolbar-item_switch", 4, 200)
 
         # Admin but with no permission
@@ -160,12 +160,12 @@ class ViewTests(SettingsOverrideTestCase):
         user.user_permissions.add(Permission.objects.get(codename='change_page'))
 
         with self.login_user_context(user):
-            response = self.client.get("/en/?edit")
+            response = self.client.get("/en/?%s" % get_cms_setting('CMS_TOOLBAR_URL__EDIT_ON'))
         self.assertNotContains(response, "cms_toolbar-item_switch", 200)
 
         PagePermission.objects.create(can_change=True, user=user, page=page)
         with self.login_user_context(user):
-            response = self.client.get("/en/?edit")
+            response = self.client.get("/en/?%s" % get_cms_setting('CMS_TOOLBAR_URL__EDIT_ON'))
         self.assertContains(response, "cms_toolbar-item_switch", 4, 200)
 
 
@@ -214,8 +214,8 @@ class ContextTests(SettingsOverrideTestCase):
             # django applications
             with self.assertNumQueries(num_queries):
                 response = self.client.get("/en/admin/")
-            # 3 queries run when determining current page
-            with self.assertNumQueries(3):
+            # One query when determining current page
+            with self.assertNumQueries(1):
                 self.assertFalse(response.context['request'].current_page)
                 self.assertFalse(response.context['request']._current_page_cache)
             # Zero more queries when determining the current template
@@ -229,7 +229,7 @@ class ContextTests(SettingsOverrideTestCase):
         # Number of queries when context processors is not enabled
         with SettingsOverride(TEMPLATE_CONTEXT_PROCESSORS=new_context):
             # Baseline number of queries
-            with self.assertNumQueries(FuzzyInt(15, 19)) as context:
+            with self.assertNumQueries(FuzzyInt(13, 17)) as context:
                 response = self.client.get("/en/page-2/")
                 if DJANGO_1_5:
                     num_queries_page = len(context.connection.queries) - context.starting_queries
