@@ -27,25 +27,18 @@ def get_page_queryset(request=None):
 
 def get_page_queryset_from_path(path, preview=False, draft=False, site=None):
     """ Returns a queryset of pages corresponding to the path given
-    In may returns None or a single page is no page is present or root path is given
     """
     if 'django.contrib.admin' in settings.INSTALLED_APPS:
         admin_base = reverse('admin:index')
-    else:
-        admin_base = None
 
-    # Check if this is called from an admin request
-    if admin_base and path.startswith(admin_base):
-        # if so, get the page ID to request it directly
-        match = ADMIN_PAGE_RE.search(path)
-        if not match:
-            page = None
-        else:
-            try:
-                page = Page.objects.get(pk=match.group(1))
-            except Page.DoesNotExist:
-                page = None
-        return page
+        # Check if this is called from an admin request
+        if path.startswith(admin_base):
+            # if so, get the page ID to request it directly
+            match = ADMIN_PAGE_RE.search(path)
+            if match:
+                return Page.objects.filter(pk=match.group(1))
+            else:
+                return Page.objects.none()
 
     if not site:
         site = Site.objects.get_current()
@@ -59,20 +52,12 @@ def get_page_queryset_from_path(path, preview=False, draft=False, site=None):
     else:
         pages = Page.objects.public().published(site=site)
 
-    # Check if there are any pages
-    if not pages.all_root().exists():
-        return None
-
-    # get the home page (needed to get the page)
-    try:
-        home = pages.filter(is_home=True, site=site)[0]
-    except IndexError:
-        home = None
+    if not path:
         # if there is no path (slashes stripped) and we found a home, this is the
-    # home page.
-    if not path and home:
-        page = home
-        return page
+        # home page.
+        # PageQuerySet.published() introduces a join to title_set which can return
+        # multiple rows. Get only the first match.
+        return pages.filter(is_home=True, site=site)[:1]
 
     # title_set__path=path should be clear, get the pages where the path of the
     # title object is equal to our path.
@@ -81,18 +66,11 @@ def get_page_queryset_from_path(path, preview=False, draft=False, site=None):
 
 def get_page_from_path(path, preview=False, draft=False):
     """ Resolves a url path to a single page object.
-    Raises exceptions is page does not exist or multiple pages are found
+    Returns None if page does not exist
     """
-    page_qs = get_page_queryset_from_path(path, preview, draft)
-    if page_qs is not None:
-        if isinstance(page_qs, Page):
-            return page_qs
-        try:
-            page = page_qs.get()
-        except Page.DoesNotExist:
-            return None
-        return page
-    else:
+    try:
+        return get_page_queryset_from_path(path, preview, draft).get()
+    except Page.DoesNotExist:
         return None
 
 
@@ -162,28 +140,24 @@ def is_valid_url(url, instance, create_links=True, site=None):
         page_qs = get_page_queryset_from_path(url.strip('/'), site=site, draft=instance.publisher_is_draft)
         url_clashes = []
         # If queryset has pages checks for conflicting urls
-        if page_qs is not None:
-            # If single page is returned create a list for interface compat
-            if isinstance(page_qs, Page):
-                page_qs = [page_qs]
-            for page in page_qs:
-                # Every page in the queryset except the current one is a conflicting page
-                # We have to exclude both copies of the page
-                if page and page.publisher_public_id != instance.pk and page.pk != instance.pk:
-                    if create_links:
-                        # Format return message with page url
-                        url_clashes.append('<a href="%(page_url)s%(pk)s" target="_blank">%(page_title)s</a>' % {
-                            'page_url': reverse('admin:cms_page_changelist'), 'pk': page.pk,
-                            'page_title': force_unicode(page),
-                        })
-                    else:
-                        # Just return the page name
-                        url_clashes.append("'%s'" % page)
-            if url_clashes:
-                # If clashing pages exist raise the exception
-                raise ValidationError(mark_safe(
-                    ungettext_lazy('Page %(pages)s has the same url \'%(url)s\' as current page "%(instance)s".',
-                                   'Pages %(pages)s have the same url \'%(url)s\' as current page "%(instance)s".',
-                                   len(url_clashes)) %
-                    {'pages': ', '.join(url_clashes), 'url': url, 'instance': instance}))
+        for page in page_qs:
+            # Every page in the queryset except the current one is a conflicting page
+            # We have to exclude both copies of the page
+            if page and page.publisher_public_id != instance.pk and page.pk != instance.pk:
+                if create_links:
+                    # Format return message with page url
+                    url_clashes.append('<a href="%(page_url)s%(pk)s" target="_blank">%(page_title)s</a>' % {
+                        'page_url': reverse('admin:cms_page_changelist'), 'pk': page.pk,
+                        'page_title': force_unicode(page),
+                    })
+                else:
+                    # Just return the page name
+                    url_clashes.append("'%s'" % page)
+        if url_clashes:
+            # If clashing pages exist raise the exception
+            raise ValidationError(mark_safe(
+                ungettext_lazy('Page %(pages)s has the same url \'%(url)s\' as current page "%(instance)s".',
+                               'Pages %(pages)s have the same url \'%(url)s\' as current page "%(instance)s".',
+                               len(url_clashes)) %
+                {'pages': ', '.join(url_clashes), 'url': url, 'instance': instance}))
     return True
